yakumo.nova.v2.key_pair

Package yakumo :: Package nova :: Package v2 :: Module key_pair |
[hide private]
[frames] | no frames]

# Module key_pair

source code

Resource class and its manager for key pairs in Compute API v2

Classes | [hide private]
| Resource Resource class for key pairs in Compute API v2
| Manager Manager class for key pairs in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``name``'``,` `'``name``'``,` <yakumo.mapper.NoopClass`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('name', 'name', mapper.Noop), ('fingerprint', 'fingerprint', mapper.
      Noop), ('public_key', 'public_key', mapper.Noop), ('user', 'user_id',
      mapper.Resource('user')), ('created_at', 'created_at', mapper.DateTime
      ), ('updated_at', 'updated_at', mapper.DateTime), ('deleted_at', 'dele
      ted_at', mapper.DateTime), ('is_deleted', 'deleted', mapper.Noop),]